# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/workspace/workspace_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.workspace import workspace_pb2 as qwak_dot_workspace_dot_workspace__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&qwak/workspace/workspace_service.proto\x12\x19qwak.workspace.management\x1a\x1eqwak/workspace/workspace.proto\"Z\n\x16\x43reateWorkspaceRequest\x12@\n\x0eworkspace_spec\x18\x01 \x01(\x0b\x32(.qwak.workspace.management.WorkspaceSpec\"/\n\x17\x43reateWorkspaceResponse\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\"p\n\x16UpdateWorkspaceRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12@\n\x0eworkspace_spec\x18\x02 \x01(\x0b\x32(.qwak.workspace.management.WorkspaceSpec\".\n\x16\x44\x65ployWorkspaceRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\"\x19\n\x17\x44\x65ployWorkspaceResponse\"0\n\x18UndeployWorkspaceRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\"\x1b\n\x19UndeployWorkspaceResponse\"\x19\n\x17UpdateWorkspaceResponse\"\x17\n\x15ListWorkspacesRequest\"R\n\x16ListWorkspacesResponse\x12\x38\n\nworkspaces\x18\x01 \x03(\x0b\x32$.qwak.workspace.management.Workspace\"/\n\x17GetWorkspaceByIdRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\"S\n\x18GetWorkspaceByIdResponse\x12\x37\n\tworkspace\x18\x01 \x01(\x0b\x32$.qwak.workspace.management.Workspace\".\n\x16\x44\x65leteWorkspaceRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\"\x19\n\x17\x44\x65leteWorkspaceResponse\"\x9a\x01\n$UpdateWorkspaceStatusFromEdgeRequest\x12r\n)update_workspace_status_from_edge_details\x18\x01 \x01(\x0b\x32?.qwak.workspace.management.UpdateWorkspaceStatusFromEdgeDetails\"\'\n%UpdateWorkspaceStatusFromEdgeResponse\"A\n\x1bRegisterWorkspaceTagRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x0c\n\x04tags\x18\x02 \x03(\t\"\x1e\n\x1cRegisterWorkspaceTagResponse\"\x1c\n\x1aListWorkspaceImagesRequest\"b\n\x1bListWorkspaceImagesResponse\x12\x43\n\x10workspace_images\x18\x01 \x03(\x0b\x32).qwak.workspace.management.WorkspaceImage\"\x18\n\x16\x43ountWorkspacesRequest\"(\n\x17\x43ountWorkspacesResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\"\"\n GetDefaultWorkspaceValuesRequest\"z\n!GetDefaultWorkspaceValuesResponse\x12U\n\x19\x64\x65\x66\x61ult_workspace_details\x18\x01 \x01(\x0b\x32\x32.qwak.workspace.management.DefaultWorkspaceDetails\"B\n\x18MarkBuildAsCopiedRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\"\x1b\n\x19MarkBuildAsCopiedResponse\":\n\x10\x43opyBuildRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\"\x13\n\x11\x43opyBuildResponse2\xaa\x0e\n\x1aWorkspaceManagementService\x12x\n\x0f\x43reateWorkspace\x12\x31.qwak.workspace.management.CreateWorkspaceRequest\x1a\x32.qwak.workspace.management.CreateWorkspaceResponse\x12x\n\x0fUpdateWorkspace\x12\x31.qwak.workspace.management.UpdateWorkspaceRequest\x1a\x32.qwak.workspace.management.UpdateWorkspaceResponse\x12x\n\x0f\x44\x65ployWorkspace\x12\x31.qwak.workspace.management.DeployWorkspaceRequest\x1a\x32.qwak.workspace.management.DeployWorkspaceResponse\x12~\n\x11UndeployWorkspace\x12\x33.qwak.workspace.management.UndeployWorkspaceRequest\x1a\x34.qwak.workspace.management.UndeployWorkspaceResponse\x12u\n\x0eListWorkspaces\x12\x30.qwak.workspace.management.ListWorkspacesRequest\x1a\x31.qwak.workspace.management.ListWorkspacesResponse\x12{\n\x10GetWorkspaceById\x12\x32.qwak.workspace.management.GetWorkspaceByIdRequest\x1a\x33.qwak.workspace.management.GetWorkspaceByIdResponse\x12x\n\x0f\x44\x65leteWorkspace\x12\x31.qwak.workspace.management.DeleteWorkspaceRequest\x1a\x32.qwak.workspace.management.DeleteWorkspaceResponse\x12\xa2\x01\n\x1dUpdateWorkspaceStatusFromEdge\x12?.qwak.workspace.management.UpdateWorkspaceStatusFromEdgeRequest\x1a@.qwak.workspace.management.UpdateWorkspaceStatusFromEdgeResponse\x12\x84\x01\n\x13ListWorkspaceImages\x12\x35.qwak.workspace.management.ListWorkspaceImagesRequest\x1a\x36.qwak.workspace.management.ListWorkspaceImagesResponse\x12\x88\x01\n\x15RegisterWorkspaceTags\x12\x36.qwak.workspace.management.RegisterWorkspaceTagRequest\x1a\x37.qwak.workspace.management.RegisterWorkspaceTagResponse\x12x\n\x0f\x43ountWorkspaces\x12\x31.qwak.workspace.management.CountWorkspacesRequest\x1a\x32.qwak.workspace.management.CountWorkspacesResponse\x12\x96\x01\n\x19GetDefaultWorkspaceValues\x12;.qwak.workspace.management.GetDefaultWorkspaceValuesRequest\x1a<.qwak.workspace.management.GetDefaultWorkspaceValuesResponse\x12~\n\x11MarkBuildAsCopied\x12\x33.qwak.workspace.management.MarkBuildAsCopiedRequest\x1a\x34.qwak.workspace.management.MarkBuildAsCopiedResponse\x12\x66\n\tCopyBuild\x12+.qwak.workspace.management.CopyBuildRequest\x1a,.qwak.workspace.management.CopyBuildResponseBB\n$com.qwak.ai.management.workspace.apiP\x01Z\x18qwak/workspace;workspaceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.workspace.workspace_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$com.qwak.ai.management.workspace.apiP\001Z\030qwak/workspace;workspace'
  _globals['_CREATEWORKSPACEREQUEST']._serialized_start=101
  _globals['_CREATEWORKSPACEREQUEST']._serialized_end=191
  _globals['_CREATEWORKSPACERESPONSE']._serialized_start=193
  _globals['_CREATEWORKSPACERESPONSE']._serialized_end=240
  _globals['_UPDATEWORKSPACEREQUEST']._serialized_start=242
  _globals['_UPDATEWORKSPACEREQUEST']._serialized_end=354
  _globals['_DEPLOYWORKSPACEREQUEST']._serialized_start=356
  _globals['_DEPLOYWORKSPACEREQUEST']._serialized_end=402
  _globals['_DEPLOYWORKSPACERESPONSE']._serialized_start=404
  _globals['_DEPLOYWORKSPACERESPONSE']._serialized_end=429
  _globals['_UNDEPLOYWORKSPACEREQUEST']._serialized_start=431
  _globals['_UNDEPLOYWORKSPACEREQUEST']._serialized_end=479
  _globals['_UNDEPLOYWORKSPACERESPONSE']._serialized_start=481
  _globals['_UNDEPLOYWORKSPACERESPONSE']._serialized_end=508
  _globals['_UPDATEWORKSPACERESPONSE']._serialized_start=510
  _globals['_UPDATEWORKSPACERESPONSE']._serialized_end=535
  _globals['_LISTWORKSPACESREQUEST']._serialized_start=537
  _globals['_LISTWORKSPACESREQUEST']._serialized_end=560
  _globals['_LISTWORKSPACESRESPONSE']._serialized_start=562
  _globals['_LISTWORKSPACESRESPONSE']._serialized_end=644
  _globals['_GETWORKSPACEBYIDREQUEST']._serialized_start=646
  _globals['_GETWORKSPACEBYIDREQUEST']._serialized_end=693
  _globals['_GETWORKSPACEBYIDRESPONSE']._serialized_start=695
  _globals['_GETWORKSPACEBYIDRESPONSE']._serialized_end=778
  _globals['_DELETEWORKSPACEREQUEST']._serialized_start=780
  _globals['_DELETEWORKSPACEREQUEST']._serialized_end=826
  _globals['_DELETEWORKSPACERESPONSE']._serialized_start=828
  _globals['_DELETEWORKSPACERESPONSE']._serialized_end=853
  _globals['_UPDATEWORKSPACESTATUSFROMEDGEREQUEST']._serialized_start=856
  _globals['_UPDATEWORKSPACESTATUSFROMEDGEREQUEST']._serialized_end=1010
  _globals['_UPDATEWORKSPACESTATUSFROMEDGERESPONSE']._serialized_start=1012
  _globals['_UPDATEWORKSPACESTATUSFROMEDGERESPONSE']._serialized_end=1051
  _globals['_REGISTERWORKSPACETAGREQUEST']._serialized_start=1053
  _globals['_REGISTERWORKSPACETAGREQUEST']._serialized_end=1118
  _globals['_REGISTERWORKSPACETAGRESPONSE']._serialized_start=1120
  _globals['_REGISTERWORKSPACETAGRESPONSE']._serialized_end=1150
  _globals['_LISTWORKSPACEIMAGESREQUEST']._serialized_start=1152
  _globals['_LISTWORKSPACEIMAGESREQUEST']._serialized_end=1180
  _globals['_LISTWORKSPACEIMAGESRESPONSE']._serialized_start=1182
  _globals['_LISTWORKSPACEIMAGESRESPONSE']._serialized_end=1280
  _globals['_COUNTWORKSPACESREQUEST']._serialized_start=1282
  _globals['_COUNTWORKSPACESREQUEST']._serialized_end=1306
  _globals['_COUNTWORKSPACESRESPONSE']._serialized_start=1308
  _globals['_COUNTWORKSPACESRESPONSE']._serialized_end=1348
  _globals['_GETDEFAULTWORKSPACEVALUESREQUEST']._serialized_start=1350
  _globals['_GETDEFAULTWORKSPACEVALUESREQUEST']._serialized_end=1384
  _globals['_GETDEFAULTWORKSPACEVALUESRESPONSE']._serialized_start=1386
  _globals['_GETDEFAULTWORKSPACEVALUESRESPONSE']._serialized_end=1508
  _globals['_MARKBUILDASCOPIEDREQUEST']._serialized_start=1510
  _globals['_MARKBUILDASCOPIEDREQUEST']._serialized_end=1576
  _globals['_MARKBUILDASCOPIEDRESPONSE']._serialized_start=1578
  _globals['_MARKBUILDASCOPIEDRESPONSE']._serialized_end=1605
  _globals['_COPYBUILDREQUEST']._serialized_start=1607
  _globals['_COPYBUILDREQUEST']._serialized_end=1665
  _globals['_COPYBUILDRESPONSE']._serialized_start=1667
  _globals['_COPYBUILDRESPONSE']._serialized_end=1686
  _globals['_WORKSPACEMANAGEMENTSERVICE']._serialized_start=1689
  _globals['_WORKSPACEMANAGEMENTSERVICE']._serialized_end=3523
# @@protoc_insertion_point(module_scope)
