# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/runtime_configuration/v0/hosting/azure/auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.runtime_configuration.v0.creds import secret_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_creds_dot_secret__pb2
from _qwak_proto.qwak.administration.runtime_configuration.v0.external.databricks import auth_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_external_dot_databricks_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEqwak/administration/runtime_configuration/v0/hosting/azure/auth.proto\x12:qwak.administration.runtime_configuration.v0.hosting.azure\x1a?qwak/administration/runtime_configuration/v0/creds/secret.proto\x1aKqwak/administration/runtime_configuration/v0/external/databricks/auth.proto\"\xa1\x01\n\x13\x41zureAuthentication\x12\x81\x01\n\x15\x61zure_databricks_auth\x18\x01 \x01(\x0b\x32`.qwak.administration.runtime_configuration.v0.hosting.azure.AzureDatabricksServiceAuthenticationH\x00\x42\x06\n\x04type\"\xfc\x01\n$AzureDatabricksServiceAuthentication\x12\x61\n\x07\x64\x62_auth\x18\x01 \x01(\x0b\x32P.qwak.administration.runtime_configuration.v0.external.databricks.DatabricksAuth\x12q\n\x17\x61zure_blob_storage_auth\x18\x02 \x01(\x0b\x32P.qwak.administration.runtime_configuration.v0.hosting.azure.AzureBlobStorageAuth\"\xf1\x01\n\x14\x41zureBlobStorageAuth\x12^\n\tsas_token\x18\x01 \x01(\x0b\x32I.qwak.administration.runtime_configuration.v0.hosting.azure.AzureSASTokenH\x00\x12l\n\x10managed_identity\x18\x02 \x01(\x0b\x32P.qwak.administration.runtime_configuration.v0.hosting.azure.AzureManagedIdentityH\x00\x42\x0b\n\tauth_type\"v\n\rAzureSASToken\x12Y\n\x06secret\x18\x01 \x01(\x0b\x32G.qwak.administration.runtime_configuration.v0.creds.secret.SecretKeyRefH\x00\x42\n\n\x08location\"\xb9\x01\n\x14\x41zureManagedIdentity\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x85\x01\n\x15\x66\x65\x64\x65rated_credentials\x18\x02 \x01(\x0b\x32\x64.qwak.administration.runtime_configuration.v0.hosting.azure.KubernetesFederatedCredentialsDescriptorH\x00\x42\x06\n\x04type\"H\n(KubernetesFederatedCredentialsDescriptor\x12\x1c\n\x14service_account_name\x18\x01 \x01(\tB\xdd\x01\n3com.jfrog.ml.runtime_configuration.v0.hosting.azureP\x01Z\xa3\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/hosting/azure;hosting_azureb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.runtime_configuration.v0.hosting.azure.auth_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n3com.jfrog.ml.runtime_configuration.v0.hosting.azureP\001Z\243\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/hosting/azure;hosting_azure'
  _globals['_AZUREAUTHENTICATION']._serialized_start=276
  _globals['_AZUREAUTHENTICATION']._serialized_end=437
  _globals['_AZUREDATABRICKSSERVICEAUTHENTICATION']._serialized_start=440
  _globals['_AZUREDATABRICKSSERVICEAUTHENTICATION']._serialized_end=692
  _globals['_AZUREBLOBSTORAGEAUTH']._serialized_start=695
  _globals['_AZUREBLOBSTORAGEAUTH']._serialized_end=936
  _globals['_AZURESASTOKEN']._serialized_start=938
  _globals['_AZURESASTOKEN']._serialized_end=1056
  _globals['_AZUREMANAGEDIDENTITY']._serialized_start=1059
  _globals['_AZUREMANAGEDIDENTITY']._serialized_end=1244
  _globals['_KUBERNETESFEDERATEDCREDENTIALSDESCRIPTOR']._serialized_start=1246
  _globals['_KUBERNETESFEDERATEDCREDENTIALSDESCRIPTOR']._serialized_end=1318
# @@protoc_insertion_point(module_scope)
