# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/integration/open_a_i_integration.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+qwak/integration/open_a_i_integration.proto\x12\x1bqwak.integration.management\"\x8f\x01\n\x11OpenAIIntegration\x12r\n\'openai_api_key_system_secret_descriptor\x18\x01 \x01(\x0b\x32?.qwak.integration.management.OpenAIApiKeySystemSecretDescriptorH\x00\x42\x06\n\x04\x61uth\"z\n\x15OpenAIIntegrationSpec\x12Y\n\x1aopenai_api_key_auth_config\x18\x01 \x01(\x0b\x32\x33.qwak.integration.management.OpenAIApiKeyAuthConfigH\x00\x42\x06\n\x04\x61uth\")\n\x16OpenAIApiKeyAuthConfig\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t\"U\n\"OpenAIApiKeySystemSecretDescriptor\x12\x13\n\x0bsecret_name\x18\x01 \x01(\t\x12\x1a\n\x12\x61pi_key_secret_key\x18\x02 \x01(\t\"y\n\x14OpenAIValidationSpec\x12Y\n\x1aopenai_api_key_auth_config\x18\x01 \x01(\x0b\x32\x33.qwak.integration.management.OpenAIApiKeyAuthConfigH\x00\x42\x06\n\x04\x61uth\"\x1a\n\x18OpenAIIntegrationOptionsBH\n&com.qwak.ai.management.integration.apiP\x01Z\x1cqwak/integration;integrationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.integration.open_a_i_integration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.management.integration.apiP\001Z\034qwak/integration;integration'
  _globals['_OPENAIINTEGRATION']._serialized_start=77
  _globals['_OPENAIINTEGRATION']._serialized_end=220
  _globals['_OPENAIINTEGRATIONSPEC']._serialized_start=222
  _globals['_OPENAIINTEGRATIONSPEC']._serialized_end=344
  _globals['_OPENAIAPIKEYAUTHCONFIG']._serialized_start=346
  _globals['_OPENAIAPIKEYAUTHCONFIG']._serialized_end=387
  _globals['_OPENAIAPIKEYSYSTEMSECRETDESCRIPTOR']._serialized_start=389
  _globals['_OPENAIAPIKEYSYSTEMSECRETDESCRIPTOR']._serialized_end=474
  _globals['_OPENAIVALIDATIONSPEC']._serialized_start=476
  _globals['_OPENAIVALIDATIONSPEC']._serialized_end=597
  _globals['_OPENAIINTEGRATIONOPTIONS']._serialized_start=599
  _globals['_OPENAIINTEGRATIONOPTIONS']._serialized_end=625
# @@protoc_insertion_point(module_scope)
