"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.administration.runtime_configuration.v0.creds.secret_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ClusterNetworkConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GATEWAY_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    @property
    def gateway(self) -> global___GatewayConfiguration: ...
    url: builtins.str
    def __init__(
        self,
        *,
        gateway: global___GatewayConfiguration | None = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gateway", b"gateway"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["gateway", b"gateway", "url", b"url"]) -> None: ...

global___ClusterNetworkConfiguration = ClusterNetworkConfiguration

class EnvironmentNetworkConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GATEWAY_FIELD_NUMBER: builtins.int
    SERVICES_URL_FIELD_NUMBER: builtins.int
    MODELS_URL_FIELD_NUMBER: builtins.int
    @property
    def gateway(self) -> global___GatewayConfiguration: ...
    services_url: builtins.str
    models_url: builtins.str
    def __init__(
        self,
        *,
        gateway: global___GatewayConfiguration | None = ...,
        services_url: builtins.str = ...,
        models_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gateway", b"gateway"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["gateway", b"gateway", "models_url", b"models_url", "services_url", b"services_url"]) -> None: ...

global___EnvironmentNetworkConfiguration = EnvironmentNetworkConfiguration

class GatewayConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISTIO_FIELD_NUMBER: builtins.int
    @property
    def istio(self) -> global___IstioGatewayConfiguration: ...
    def __init__(
        self,
        *,
        istio: global___IstioGatewayConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["istio", b"istio", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["istio", b"istio", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["istio"] | None: ...

global___GatewayConfiguration = GatewayConfiguration

class IstioGatewayConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_FIELD_NUMBER: builtins.int
    @property
    def certificate(self) -> qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef: ...
    def __init__(
        self,
        *,
        certificate: qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["certificate", b"certificate"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate", b"certificate"]) -> None: ...

global___IstioGatewayConfiguration = IstioGatewayConfiguration

class Certificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_FIELD_NUMBER: builtins.int
    @property
    def secret(self) -> qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef: ...
    def __init__(
        self,
        *,
        secret: qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["location", b"location", "secret", b"secret"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "secret", b"secret"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["location", b"location"]) -> typing_extensions.Literal["secret"] | None: ...

global___Certificate = Certificate
