# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.builds import builds_orchestrator_service_pb2 as qwak_dot_builds_dot_builds__orchestrator__service__pb2


class BuildsOrchestratorServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.BuildModel = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/BuildModel',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.BuildModelRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.BuildModelResponse.FromString,
                )
        self.CancelBuildModel = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/CancelBuildModel',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.CancelBuildModelRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.CancelBuildModelResponse.FromString,
                )
        self.CreateUploadURL = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/CreateUploadURL',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.CreateUploadURLRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.CreateUploadURLResponse.FromString,
                )
        self.GetBuildVersioningUploadURL = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/GetBuildVersioningUploadURL',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningUploadURLRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningUploadURLResponse.FromString,
                )
        self.GetBuildVersioningUploadUrls = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/GetBuildVersioningUploadUrls',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningUploadUrlsRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningUploadUrlsResponse.FromString,
                )
        self.GetBuildVersioningDownloadURL = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/GetBuildVersioningDownloadURL',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningDownloadURLRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningDownloadURLResponse.FromString,
                )
        self.GetBuildVersioningDownloadUrls = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/GetBuildVersioningDownloadUrls',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningDownloadUrLsRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningDownloadUrlsResponse.FromString,
                )
        self.ListBuildVersioningTags = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/ListBuildVersioningTags',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.ListBuildVersioningTagsRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.ListBuildVersioningTagsResponse.FromString,
                )
        self.CreateDataTable = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/CreateDataTable',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.CreateDataTableRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.CreateDataTableResponse.FromString,
                )
        self.GetBaseDockerImageName = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/GetBaseDockerImageName',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBaseDockerImageNameRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBaseDockerImageNameResponse.FromString,
                )
        self.SaveArtifactPath = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/SaveArtifactPath',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.SaveArtifactPathRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.SaveArtifactPathResponse.FromString,
                )
        self.ListBuildArtifacts = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/ListBuildArtifacts',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.ListBuildArtifactsRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.ListBuildArtifactsResponse.FromString,
                )
        self.DetachBuildsFromModelVersions = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/DetachBuildsFromModelVersions',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.DetachBuildsFromModelVersionsRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.DetachBuildsFromModelVersionsResponse.FromString,
                )


class BuildsOrchestratorServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def BuildModel(self, request, context):
        """Build a serving model image
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelBuildModel(self, request, context):
        """Cancel an ongoing build
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateUploadURL(self, request, context):
        """Request the service for a path ready for upload in purpose of uploading local model code available to the service
        and the download link corresponding
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBuildVersioningUploadURL(self, request, context):
        """Request the service for a path ready for upload in purpose of uploading local model code or data
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBuildVersioningUploadUrls(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBuildVersioningDownloadURL(self, request, context):
        """Request the service for a path ready for download the artifact
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBuildVersioningDownloadUrls(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBuildVersioningTags(self, request, context):
        """Request the service for a list of paths ready for download the artifact
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDataTable(self, request, context):
        """Create data table for build.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBaseDockerImageName(self, request, context):
        """Get the base docker image name for the given Base Image Docker Type
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SaveArtifactPath(self, request, context):
        """Save the artifact path to the database
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBuildArtifacts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DetachBuildsFromModelVersions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BuildsOrchestratorServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'BuildModel': grpc.unary_unary_rpc_method_handler(
                    servicer.BuildModel,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.BuildModelRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.BuildModelResponse.SerializeToString,
            ),
            'CancelBuildModel': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelBuildModel,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.CancelBuildModelRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.CancelBuildModelResponse.SerializeToString,
            ),
            'CreateUploadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUploadURL,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.CreateUploadURLRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.CreateUploadURLResponse.SerializeToString,
            ),
            'GetBuildVersioningUploadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBuildVersioningUploadURL,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningUploadURLRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningUploadURLResponse.SerializeToString,
            ),
            'GetBuildVersioningUploadUrls': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBuildVersioningUploadUrls,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningUploadUrlsRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningUploadUrlsResponse.SerializeToString,
            ),
            'GetBuildVersioningDownloadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBuildVersioningDownloadURL,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningDownloadURLRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningDownloadURLResponse.SerializeToString,
            ),
            'GetBuildVersioningDownloadUrls': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBuildVersioningDownloadUrls,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningDownloadUrLsRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningDownloadUrlsResponse.SerializeToString,
            ),
            'ListBuildVersioningTags': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBuildVersioningTags,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.ListBuildVersioningTagsRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.ListBuildVersioningTagsResponse.SerializeToString,
            ),
            'CreateDataTable': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDataTable,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.CreateDataTableRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.CreateDataTableResponse.SerializeToString,
            ),
            'GetBaseDockerImageName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBaseDockerImageName,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBaseDockerImageNameRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBaseDockerImageNameResponse.SerializeToString,
            ),
            'SaveArtifactPath': grpc.unary_unary_rpc_method_handler(
                    servicer.SaveArtifactPath,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.SaveArtifactPathRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.SaveArtifactPathResponse.SerializeToString,
            ),
            'ListBuildArtifacts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBuildArtifacts,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.ListBuildArtifactsRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.ListBuildArtifactsResponse.SerializeToString,
            ),
            'DetachBuildsFromModelVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.DetachBuildsFromModelVersions,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.DetachBuildsFromModelVersionsRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.DetachBuildsFromModelVersionsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.builds.orchestrator.BuildsOrchestratorService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class BuildsOrchestratorService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def BuildModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/BuildModel',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.BuildModelRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.BuildModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelBuildModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/CancelBuildModel',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.CancelBuildModelRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.CancelBuildModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateUploadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/CreateUploadURL',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.CreateUploadURLRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.CreateUploadURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBuildVersioningUploadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/GetBuildVersioningUploadURL',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningUploadURLRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningUploadURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBuildVersioningUploadUrls(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/GetBuildVersioningUploadUrls',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningUploadUrlsRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningUploadUrlsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBuildVersioningDownloadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/GetBuildVersioningDownloadURL',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningDownloadURLRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningDownloadURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBuildVersioningDownloadUrls(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/GetBuildVersioningDownloadUrls',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningDownloadUrLsRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningDownloadUrlsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListBuildVersioningTags(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/ListBuildVersioningTags',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.ListBuildVersioningTagsRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.ListBuildVersioningTagsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDataTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/CreateDataTable',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.CreateDataTableRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.CreateDataTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBaseDockerImageName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/GetBaseDockerImageName',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBaseDockerImageNameRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBaseDockerImageNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SaveArtifactPath(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/SaveArtifactPath',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.SaveArtifactPathRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.SaveArtifactPathResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListBuildArtifacts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/ListBuildArtifacts',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.ListBuildArtifactsRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.ListBuildArtifactsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DetachBuildsFromModelVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/DetachBuildsFromModelVersions',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.DetachBuildsFromModelVersionsRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.DetachBuildsFromModelVersionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
