"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.administration.runtime_configuration.v0.creds.auth_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class KafkaConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOOTSTRAP_SERVERS_FIELD_NUMBER: builtins.int
    BASIC_AUTH_FIELD_NUMBER: builtins.int
    SECURITY_PROTOCOL_FIELD_NUMBER: builtins.int
    bootstrap_servers: builtins.str
    @property
    def basic_auth(self) -> qwak.administration.runtime_configuration.v0.creds.auth_pb2.BasicAuth: ...
    @property
    def security_protocol(self) -> global___KafkaSecurityProtocolConfig: ...
    def __init__(
        self,
        *,
        bootstrap_servers: builtins.str = ...,
        basic_auth: qwak.administration.runtime_configuration.v0.creds.auth_pb2.BasicAuth | None = ...,
        security_protocol: global___KafkaSecurityProtocolConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "basic_auth", b"basic_auth", "security_protocol", b"security_protocol"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "basic_auth", b"basic_auth", "bootstrap_servers", b"bootstrap_servers", "security_protocol", b"security_protocol"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth", b"auth"]) -> typing_extensions.Literal["basic_auth", "security_protocol"] | None: ...

global___KafkaConfiguration = KafkaConfiguration

class KafkaSecurityProtocolConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAIN_TEXT_FIELD_NUMBER: builtins.int
    SSL_FIELD_NUMBER: builtins.int
    @property
    def plain_text(self) -> global___KafkaPlainTextSecurityProtocolConfig: ...
    @property
    def ssl(self) -> global___KafkaSslSecurityProtocolConfig: ...
    def __init__(
        self,
        *,
        plain_text: global___KafkaPlainTextSecurityProtocolConfig | None = ...,
        ssl: global___KafkaSslSecurityProtocolConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["plain_text", b"plain_text", "security_protocol", b"security_protocol", "ssl", b"ssl"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["plain_text", b"plain_text", "security_protocol", b"security_protocol", "ssl", b"ssl"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["security_protocol", b"security_protocol"]) -> typing_extensions.Literal["plain_text", "ssl"] | None: ...

global___KafkaSecurityProtocolConfig = KafkaSecurityProtocolConfig

class KafkaPlainTextSecurityProtocolConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___KafkaPlainTextSecurityProtocolConfig = KafkaPlainTextSecurityProtocolConfig

class KafkaSslSecurityProtocolConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___KafkaSslSecurityProtocolConfig = KafkaSslSecurityProtocolConfig
