"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class LogLine(google.protobuf.message.Message):
    """Represent a log line"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TEXT_FIELD_NUMBER: builtins.int
    SOURCE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    INGESTED_ISO_TIMESTAMP_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    text: builtins.str
    """Text of the log"""
    source_instance_id: builtins.str
    """Id of the instance which output the line"""
    ingested_iso_timestamp: builtins.str
    """The timestamp the log was ingested"""
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Metadata for the log ling"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        source_instance_id: builtins.str = ...,
        ingested_iso_timestamp: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ingested_iso_timestamp", b"ingested_iso_timestamp", "metadata", b"metadata", "source_instance_id", b"source_instance_id", "text", b"text"]) -> None: ...

global___LogLine = LogLine
