# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.admiral.secret.v0 import system_secret_service_pb2 as qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2


class SystemSecretServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetSystemSecret = channel.unary_unary(
                '/qwak.admiral.secret.v0.SystemSecretService/SetSystemSecret',
                request_serializer=qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.SetSystemSecretRequest.SerializeToString,
                response_deserializer=qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.SetSystemSecretResponse.FromString,
                )
        self.DeleteSystemSecret = channel.unary_unary(
                '/qwak.admiral.secret.v0.SystemSecretService/DeleteSystemSecret',
                request_serializer=qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.DeleteSystemSecretRequest.SerializeToString,
                response_deserializer=qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.DeleteSystemSecretResponse.FromString,
                )
        self.GetSystemSecret = channel.unary_unary(
                '/qwak.admiral.secret.v0.SystemSecretService/GetSystemSecret',
                request_serializer=qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.GetSystemSecretRequest.SerializeToString,
                response_deserializer=qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.GetSystemSecretResponse.FromString,
                )


class SystemSecretServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SetSystemSecret(self, request, context):
        """Set a value for a secret
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSystemSecret(self, request, context):
        """Delete secret
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSystemSecret(self, request, context):
        """Get secret
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SystemSecretServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetSystemSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.SetSystemSecret,
                    request_deserializer=qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.SetSystemSecretRequest.FromString,
                    response_serializer=qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.SetSystemSecretResponse.SerializeToString,
            ),
            'DeleteSystemSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSystemSecret,
                    request_deserializer=qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.DeleteSystemSecretRequest.FromString,
                    response_serializer=qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.DeleteSystemSecretResponse.SerializeToString,
            ),
            'GetSystemSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSystemSecret,
                    request_deserializer=qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.GetSystemSecretRequest.FromString,
                    response_serializer=qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.GetSystemSecretResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.admiral.secret.v0.SystemSecretService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SystemSecretService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SetSystemSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.admiral.secret.v0.SystemSecretService/SetSystemSecret',
            qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.SetSystemSecretRequest.SerializeToString,
            qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.SetSystemSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSystemSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.admiral.secret.v0.SystemSecretService/DeleteSystemSecret',
            qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.DeleteSystemSecretRequest.SerializeToString,
            qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.DeleteSystemSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSystemSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.admiral.secret.v0.SystemSecretService/GetSystemSecret',
            qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.GetSystemSecretRequest.SerializeToString,
            qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.GetSystemSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
