# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.self_service.account.v0 import managing_account_service_pb2 as qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2


class ManagingAccountServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateAccountCreationRequest = channel.unary_unary(
                '/qwak.self_service.account.v0.ManagingAccountService/CreateAccountCreationRequest',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.CreateAccountCreationRequestRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.CreateAccountCreationRequestResponse.FromString,
                )
        self.ValidateAccountCreationRequest = channel.unary_unary(
                '/qwak.self_service.account.v0.ManagingAccountService/ValidateAccountCreationRequest',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.ValidateAccountCreationRequestRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.ValidateAccountCreationRequestResponse.FromString,
                )
        self.GetAccountStatus = channel.unary_unary(
                '/qwak.self_service.account.v0.ManagingAccountService/GetAccountStatus',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.GetAccountStatusRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.GetAccountStatusResponse.FromString,
                )
        self.GetCloudProviderSupportedRegions = channel.unary_unary(
                '/qwak.self_service.account.v0.ManagingAccountService/GetCloudProviderSupportedRegions',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.GetCloudProviderSupportedRegionsRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.GetCloudProviderSupportedRegionsResponse.FromString,
                )


class ManagingAccountServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateAccountCreationRequest(self, request, context):
        """Create account creation request
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateAccountCreationRequest(self, request, context):
        """Validate account creation request
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccountStatus(self, request, context):
        """Get account status
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCloudProviderSupportedRegions(self, request, context):
        """List all supported regions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ManagingAccountServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateAccountCreationRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAccountCreationRequest,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.CreateAccountCreationRequestRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.CreateAccountCreationRequestResponse.SerializeToString,
            ),
            'ValidateAccountCreationRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateAccountCreationRequest,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.ValidateAccountCreationRequestRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.ValidateAccountCreationRequestResponse.SerializeToString,
            ),
            'GetAccountStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccountStatus,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.GetAccountStatusRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.GetAccountStatusResponse.SerializeToString,
            ),
            'GetCloudProviderSupportedRegions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCloudProviderSupportedRegions,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.GetCloudProviderSupportedRegionsRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.GetCloudProviderSupportedRegionsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.self_service.account.v0.ManagingAccountService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ManagingAccountService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateAccountCreationRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.ManagingAccountService/CreateAccountCreationRequest',
            qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.CreateAccountCreationRequestRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.CreateAccountCreationRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateAccountCreationRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.ManagingAccountService/ValidateAccountCreationRequest',
            qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.ValidateAccountCreationRequestRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.ValidateAccountCreationRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAccountStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.ManagingAccountService/GetAccountStatus',
            qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.GetAccountStatusRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.GetAccountStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCloudProviderSupportedRegions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.ManagingAccountService/GetCloudProviderSupportedRegions',
            qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.GetCloudProviderSupportedRegionsRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.GetCloudProviderSupportedRegionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
