"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class SecretKeyRef(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KUBERNETES_SECRET_KEY_REF_FIELD_NUMBER: builtins.int
    @property
    def kubernetes_secret_key_ref(self) -> global___KubernetesSecretKeyRef: ...
    def __init__(
        self,
        *,
        kubernetes_secret_key_ref: global___KubernetesSecretKeyRef | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["kubernetes_secret_key_ref", b"kubernetes_secret_key_ref", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kubernetes_secret_key_ref", b"kubernetes_secret_key_ref", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["kubernetes_secret_key_ref"] | None: ...

global___SecretKeyRef = SecretKeyRef

class KubernetesSecretKeyRef(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    name: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "name", b"name"]) -> None: ...

global___KubernetesSecretKeyRef = KubernetesSecretKeyRef
