# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/deployment/alert_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.deployment import alert_pb2 as qwak_dot_deployment_dot_alert__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#qwak/deployment/alert_service.proto\x12\x1aqwak.deployment.management\x1a\x1bqwak/deployment/alert.proto\"`\n\x1dGetAlertsConfigurationRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x16\n\x0e\x65nvironment_id\x18\x03 \x01(\t\"W\n\x1eGetAlertsConfigurationResponse\x12\x35\n\x06\x61lerts\x18\x01 \x03(\x0b\x32%.qwak.deployment.management.AlertRule\"\xad\x01\n\x1f\x41pplyAlertsConfigurationRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x35\n\x06\x61lerts\x18\x03 \x03(\x0b\x32%.qwak.deployment.management.AlertRule\x12\x12\n\nmodel_uuid\x18\x04 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x05 \x01(\t\"\"\n ApplyAlertsConfigurationResponse\"<\n\"GetNotificationChannelsListRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"y\n#GetNotificationChannelsListResponse\x12R\n\x15notification_channels\x18\x01 \x03(\x0b\x32\x33.qwak.deployment.management.NotificationChannelSpec\"\x88\x01\n\x1f\x41pplyNotificationChannelRequest\x12M\n\x14notification_channel\x18\x01 \x01(\x0b\x32/.qwak.deployment.management.NotificationChannel\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\"\"\n ApplyNotificationChannelResponse\"[\n DeleteNotificationChannelRequest\x12\x1f\n\x17notification_channel_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\"#\n!DeleteNotificationChannelResponse\"B\n(GetNotificationChannelDetailsListRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"{\n)GetNotificationChannelDetailsListResponse\x12N\n\x15notification_channels\x18\x01 \x03(\x0b\x32/.qwak.deployment.management.NotificationChannel2\xc9\x07\n\x16\x41lertManagementService\x12\x8f\x01\n\x16GetAlertsConfiguration\x12\x39.qwak.deployment.management.GetAlertsConfigurationRequest\x1a:.qwak.deployment.management.GetAlertsConfigurationResponse\x12\x95\x01\n\x18\x41pplyAlertsConfiguration\x12;.qwak.deployment.management.ApplyAlertsConfigurationRequest\x1a<.qwak.deployment.management.ApplyAlertsConfigurationResponse\x12\x9e\x01\n\x1bGetNotificationChannelsList\x12>.qwak.deployment.management.GetNotificationChannelsListRequest\x1a?.qwak.deployment.management.GetNotificationChannelsListResponse\x12\x95\x01\n\x18\x41pplyNotificationChannel\x12;.qwak.deployment.management.ApplyNotificationChannelRequest\x1a<.qwak.deployment.management.ApplyNotificationChannelResponse\x12\x98\x01\n\x19\x44\x65leteNotificationChannel\x12<.qwak.deployment.management.DeleteNotificationChannelRequest\x1a=.qwak.deployment.management.DeleteNotificationChannelResponse\x12\xb0\x01\n!GetNotificationChannelDetailsList\x12\x44.qwak.deployment.management.GetNotificationChannelDetailsListRequest\x1a\x45.qwak.deployment.management.GetNotificationChannelDetailsListResponseB)\n%com.qwak.ai.management.deployment.apiP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.deployment.alert_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.management.deployment.apiP\001'
  _GETALERTSCONFIGURATIONREQUEST.fields_by_name['branch_id']._options = None
  _GETALERTSCONFIGURATIONREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _APPLYALERTSCONFIGURATIONREQUEST.fields_by_name['branch_id']._options = None
  _APPLYALERTSCONFIGURATIONREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _globals['_GETALERTSCONFIGURATIONREQUEST']._serialized_start=96
  _globals['_GETALERTSCONFIGURATIONREQUEST']._serialized_end=192
  _globals['_GETALERTSCONFIGURATIONRESPONSE']._serialized_start=194
  _globals['_GETALERTSCONFIGURATIONRESPONSE']._serialized_end=281
  _globals['_APPLYALERTSCONFIGURATIONREQUEST']._serialized_start=284
  _globals['_APPLYALERTSCONFIGURATIONREQUEST']._serialized_end=457
  _globals['_APPLYALERTSCONFIGURATIONRESPONSE']._serialized_start=459
  _globals['_APPLYALERTSCONFIGURATIONRESPONSE']._serialized_end=493
  _globals['_GETNOTIFICATIONCHANNELSLISTREQUEST']._serialized_start=495
  _globals['_GETNOTIFICATIONCHANNELSLISTREQUEST']._serialized_end=555
  _globals['_GETNOTIFICATIONCHANNELSLISTRESPONSE']._serialized_start=557
  _globals['_GETNOTIFICATIONCHANNELSLISTRESPONSE']._serialized_end=678
  _globals['_APPLYNOTIFICATIONCHANNELREQUEST']._serialized_start=681
  _globals['_APPLYNOTIFICATIONCHANNELREQUEST']._serialized_end=817
  _globals['_APPLYNOTIFICATIONCHANNELRESPONSE']._serialized_start=819
  _globals['_APPLYNOTIFICATIONCHANNELRESPONSE']._serialized_end=853
  _globals['_DELETENOTIFICATIONCHANNELREQUEST']._serialized_start=855
  _globals['_DELETENOTIFICATIONCHANNELREQUEST']._serialized_end=946
  _globals['_DELETENOTIFICATIONCHANNELRESPONSE']._serialized_start=948
  _globals['_DELETENOTIFICATIONCHANNELRESPONSE']._serialized_end=983
  _globals['_GETNOTIFICATIONCHANNELDETAILSLISTREQUEST']._serialized_start=985
  _globals['_GETNOTIFICATIONCHANNELDETAILSLISTREQUEST']._serialized_end=1051
  _globals['_GETNOTIFICATIONCHANNELDETAILSLISTRESPONSE']._serialized_start=1053
  _globals['_GETNOTIFICATIONCHANNELDETAILSLISTRESPONSE']._serialized_end=1176
  _globals['_ALERTMANAGEMENTSERVICE']._serialized_start=1179
  _globals['_ALERTMANAGEMENTSERVICE']._serialized_end=2148
# @@protoc_insertion_point(module_scope)
