# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/builds/builds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.deployment import deployment_pb2 as qwak_dot_deployment_dot_deployment__pb2
from _qwak_proto.qwak.builds import build_pb2 as qwak_dot_builds_dot_build__pb2
from _qwak_proto.qwak.fitness_service import status_pb2 as qwak_dot_fitness__service_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18qwak/builds/builds.proto\x12\x16qwak.builds.management\x1a\x1fgoogle/protobuf/timestamp.proto\x1a qwak/deployment/deployment.proto\x1a\x17qwak/builds/build.proto\x1a!qwak/fitness_service/status.proto\"\xf4\x05\n\x05\x42uild\x12\x35\n\nbuild_spec\x18\x01 \x01(\x0b\x32!.qwak.builds.management.BuildSpec\x12\x39\n\x0c\x62uild_status\x18\x02 \x01(\x0e\x32#.qwak.builds.management.BuildStatus\x12\x39\n\x0cmodel_schema\x18\x03 \x01(\x0b\x32#.qwak.builds.management.ModelSchema\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12\x34\n\x10last_modified_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x07 \x01(\t\x12V\n\x17\x64\x65ployment_build_status\x18\x08 \x01(\x0e\x32\x31.qwak.deployment.management.ModelDeploymentStatusB\x02\x18\x01\x12V\n\x14hosting_service_type\x18\t \x01(\x0e\x32\x38.qwak.deployment.management.DeploymentHostingServiceType\x12,\n\x08\x65nd_date\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1e\n\x16\x61vailable_environments\x18\x0b \x03(\t\x12\x1d\n\x15\x64\x65ployed_environments\x18\x0c \x03(\t\x12\x32\n\tpodStatus\x18\r \x01(\x0b\x32\x1f.qwak.fitness.service.PodStatus\x12\x16\n\x0eimage_name_tag\x18\x0e \x01(\t\x12\x41\n\x0f\x62uild_initiator\x18\x0f \x01(\x0b\x32(.qwak.builds.orchestrator.BuildInitiator\"\x86\x03\n\tBuildSpec\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x11\n\tcommit_id\x18\x02 \x01(\t\x12\x10\n\x08model_id\x18\x03 \x01(\t\x12\x13\n\x0b\x62ranch_name\x18\x04 \x01(\t\x12\x11\n\tbranch_id\x18\x08 \x01(\t\x12\x0c\n\x04tags\x18\x05 \x03(\t\x12T\n\x1a\x65xperiment_tracking_values\x18\x06 \x01(\x0b\x32\x30.qwak.builds.management.ExperimentTrackingValues\x12G\n\x13\x62uild_configuration\x18\x07 \x01(\x0b\x32*.qwak.builds.management.BuildConfiguration\x12\x17\n\x0f\x62uild_code_path\x18\t \x01(\t\x12\x13\n\x0b\x62uild_steps\x18\n \x03(\t\x12\x16\n\x0e\x65nvironment_id\x18\x0b \x01(\t\x12\x12\n\nmodel_uuid\x18\x0c \x01(\t\x12\x13\n\x0bsdk_version\x18\r \x01(\t\"\xee\x01\n\x0bModelSchema\x12\x30\n\x08\x65ntities\x18\x01 \x03(\x0b\x32\x1e.qwak.builds.management.Entity\x12\x31\n\x08\x66\x65\x61tures\x18\x02 \x03(\x0b\x32\x1f.qwak.builds.management.Feature\x12\x37\n\x0bpredictions\x18\x03 \x03(\x0b\x32\".qwak.builds.management.Prediction\x12\x41\n\x10inference_output\x18\x04 \x03(\x0b\x32\'.qwak.builds.management.InferenceOutput\"G\n\x06\x45ntity\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0b\x32!.qwak.builds.management.ValueType\"\xd0\x04\n\x07\x46\x65\x61ture\x12=\n\rbatch_feature\x18\x01 \x01(\x0b\x32$.qwak.builds.management.BatchFeatureH\x00\x12\x43\n\x10\x65xplicit_feature\x18\x02 \x01(\x0b\x32\'.qwak.builds.management.ExplicitFeatureH\x00\x12\x45\n\x12on_the_fly_feature\x18\x03 \x01(\x0b\x32\'.qwak.builds.management.OnTheFlyFeatureH\x00\x12\x45\n\x11streaming_feature\x18\x04 \x01(\x0b\x32(.qwak.builds.management.StreamingFeatureH\x00\x12=\n\rrequest_input\x18\x05 \x01(\x0b\x32$.qwak.builds.management.RequestInputH\x00\x12\\\n\x1dstreaming_aggregation_feature\x18\x06 \x01(\x0b\x32\x33.qwak.builds.management.StreamingAggregationFeatureH\x00\x12\x42\n\x10\x62\x61tch_feature_v1\x18\x07 \x01(\x0b\x32&.qwak.builds.management.BatchFeatureV1H\x00\x12J\n\x14streaming_feature_v1\x18\x08 \x01(\x0b\x32*.qwak.builds.management.StreamingFeatureV1H\x00\x42\x06\n\x04type\"\x8f\x01\n\x0fOnTheFlyFeature\x12.\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x1e.qwak.builds.management.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\x12>\n\x0fsource_features\x18\x03 \x03(\x0b\x32%.qwak.builds.management.SourceFeature\"N\n\x0e\x42\x61tchFeatureV1\x12.\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x1e.qwak.builds.management.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"R\n\x12StreamingFeatureV1\x12.\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x1e.qwak.builds.management.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"L\n\x0c\x42\x61tchFeature\x12.\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x1e.qwak.builds.management.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"P\n\x10StreamingFeature\x12.\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x1e.qwak.builds.management.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"[\n\x1bStreamingAggregationFeature\x12.\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x1e.qwak.builds.management.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"P\n\x0f\x45xplicitFeature\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0b\x32!.qwak.builds.management.ValueType\"M\n\x0cRequestInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0b\x32!.qwak.builds.management.ValueType\"\x9b\x01\n\rSourceFeature\x12\x43\n\x10\x65xplicit_feature\x18\x01 \x01(\x0b\x32\'.qwak.builds.management.ExplicitFeatureH\x00\x12=\n\rrequest_input\x18\x02 \x01(\x0b\x32$.qwak.builds.management.RequestInputH\x00\x42\x06\n\x04type\"K\n\nPrediction\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0b\x32!.qwak.builds.management.ValueType\"P\n\x0fInferenceOutput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0b\x32!.qwak.builds.management.ValueType\"\xa6\x01\n\tValueType\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.qwak.builds.management.ValueType.Types\"b\n\x05Types\x12\x0b\n\x07INVALID\x10\x00\x12\t\n\x05\x42YTES\x10\x01\x12\n\n\x06STRING\x10\x02\x12\t\n\x05INT32\x10\x03\x12\t\n\x05INT64\x10\x04\x12\n\n\x06\x44OUBLE\x10\x05\x12\t\n\x05\x46LOAT\x10\x06\x12\x08\n\x04\x42OOL\x10\x07\"j\n\x11ParameterCategory\"U\n\x08\x43\x61tegory\x12\x0b\n\x07INVALID\x10\x00\x12\n\n\x06\x45NTITY\x10\x01\x12\x0b\n\x07\x46\x45\x41TURE\x10\x02\x12\x0e\n\nPREDICTION\x10\x03\x12\x13\n\x0fINFERENCEOUTPUT\x10\x04\"i\n\x1aRegisterModelSchemaRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x39\n\x0cmodel_schema\x18\x02 \x01(\x0b\x32#.qwak.builds.management.ModelSchema\"\x91\x01\n\'RegisterExperimentTrackingValuesRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12T\n\x1a\x65xperiment_tracking_values\x18\x02 \x01(\x0b\x32\x30.qwak.builds.management.ExperimentTrackingValues\"*\n(RegisterExperimentTrackingValuesResponse\"z\n\x18\x45xperimentTrackingValues\x12/\n\x07metrics\x18\x01 \x03(\x0b\x32\x1e.qwak.builds.management.Metric\x12-\n\x06params\x18\x02 \x03(\x0b\x32\x1d.qwak.builds.management.Param\"\xd1\x02\n\x12\x42uildConfiguration\x12\x46\n\x10\x62uild_properties\x18\x01 \x01(\x0b\x32,.qwak.builds.management.BuildPropertiesProto\x12;\n\tbuild_env\x18\x02 \x01(\x0b\x32(.qwak.builds.management.BuildEnvironment\x12;\n\tpre_build\x18\x03 \x01(\x0b\x32(.qwak.builds.management.BuildEnvironment\x12<\n\npost_build\x18\x04 \x01(\x0b\x32(.qwak.builds.management.BuildEnvironment\x12*\n\x04step\x18\x05 \x01(\x0b\x32\x1c.qwak.builds.management.Step\x12\x0f\n\x07verbose\x18\x06 \x01(\x05\"_\n\x04Step\x12\r\n\x05tests\x18\x01 \x01(\x08\x12\x1f\n\x17validate_build_artifact\x18\x02 \x01(\x08\x12\'\n\x1fvalidate_build_artifact_timeout\x18\x03 \x01(\x05\"\xc4\x01\n\x14\x42uildPropertiesProto\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x38\n\tmodel_uri\x18\x02 \x01(\x0b\x32%.qwak.builds.management.BuildModelUri\x12\x0c\n\x04tags\x18\x03 \x03(\t\x12\x10\n\x08\x62uild_id\x18\x04 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x05 \x01(\t\x12\x18\n\x10\x65nvironment_name\x18\x06 \x01(\t\x12\x16\n\x0egpu_compatible\x18\x07 \x01(\x08\"g\n\rBuildModelUri\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x12\n\ngit_branch\x18\x02 \x01(\t\x12\x10\n\x08main_dir\x18\x03 \x01(\t\x12#\n\x1b\x64\x65pendency_required_folders\x18\x04 \x03(\t\"\xe8\x01\n\x10\x42uildEnvironment\x12\x33\n\x06\x64ocker\x18\x01 \x01(\x0b\x32#.qwak.builds.management.DockerBuild\x12\x31\n\x05local\x18\x02 \x01(\x0b\x32\".qwak.builds.management.LocalBuild\x12\x37\n\npython_env\x18\x03 \x01(\x0b\x32#.qwak.builds.management.PythonBuild\x12\x33\n\x06remote\x18\x04 \x01(\x0b\x32#.qwak.builds.management.RemoteBuild\"\x8a\x02\n\x0b\x44ockerBuild\x12\x12\n\nbase_image\x18\x01 \x01(\t\x12\x46\n\nbuild_args\x18\x02 \x03(\x0b\x32\x32.qwak.builds.management.DockerBuild.BuildArgsEntry\x12\x10\n\x08\x65nv_vars\x18\x03 \x03(\t\x12\x10\n\x08no_cache\x18\x04 \x01(\x08\x12\x0e\n\x06params\x18\x05 \x03(\t\x12\x1c\n\x14\x61ssumed_iam_role_arn\x18\x06 \x01(\t\x12\r\n\x05\x63\x61\x63he\x18\x07 \x01(\x08\x12\x0c\n\x04push\x18\x08 \x01(\x08\x1a\x30\n\x0e\x42uildArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"2\n\nLocalBuild\x12\x13\n\x0b\x61ws_profile\x18\x01 \x01(\t\x12\x0f\n\x07no_push\x18\x02 \x01(\x08\"\x9b\x02\n\x0bPythonBuild\x12 \n\x18qwak_sdk_extra_index_url\x18\x01 \x01(\t\x12\x43\n\nvirtualenv\x18\x02 \x01(\x0b\x32/.qwak.builds.management.VirtualEnvironmentBuild\x12\x31\n\x05\x63onda\x18\x03 \x01(\x0b\x32\".qwak.builds.management.CondaBuild\x12\x33\n\x06poetry\x18\x04 \x01(\x0b\x32#.qwak.builds.management.PoetryBuild\x12\x1c\n\x14\x64\x65pendency_file_path\x18\x05 \x01(\t\x12\x1f\n\x17use_deprecated_resolver\x18\x06 \x01(\x08\" \n\nCondaBuild\x12\x12\n\nconda_file\x18\x01 \x01(\t\"8\n\x0bPoetryBuild\x12\x16\n\x0epython_version\x18\x01 \x01(\t\x12\x11\n\tlock_file\x18\x02 \x01(\t\"K\n\x17VirtualEnvironmentBuild\x12\x16\n\x0epython_version\x18\x01 \x01(\t\x12\x18\n\x10requirements_txt\x18\x02 \x01(\t\"a\n\x0bRemoteBuild\x12\x11\n\tis_remote\x18\x01 \x01(\x08\x12?\n\tresources\x18\x02 \x01(\x0b\x32,.qwak.builds.management.RemoteBuildResources\"\x8f\x01\n\x14RemoteBuildResources\x12\x0c\n\x04\x63pus\x18\x01 \x01(\x02\x12\x0e\n\x06memory\x18\x02 \x01(\t\x12\x33\n\x08gpu_type\x18\x03 \x01(\x0e\x32!.qwak.builds.orchestrator.GpuType\x12\x12\n\ngpu_amount\x18\x04 \x01(\x05\x12\x10\n\x08instance\x18\x05 \x01(\t\"$\n\x06Metric\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02\"#\n\x05Param\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t*\xe8\x01\n\x0b\x42uildStatus\x12\x0b\n\x07INVALID\x10\x00\x12\x0f\n\x0bIN_PROGRESS\x10\x01\x12\x0e\n\nSUCCESSFUL\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\x1d\n\x19REMOTE_BUILD_INITIALIZING\x10\x04\x12\x1a\n\x16REMOTE_BUILD_CANCELLED\x10\x05\x12\x1a\n\x16REMOTE_BUILD_TIMED_OUT\x10\x06\x12\x18\n\x14REMOTE_BUILD_UNKNOWN\x10\x07\x12\x18\n\x14SYNCING_ENVIRONMENTS\x10\x08\x12\x14\n\x10\x46INISHED_SYNCING\x10\tB%\n!com.qwak.ai.management.builds.apiP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.builds.builds_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.qwak.ai.management.builds.apiP\001'
  _BUILD.fields_by_name['deployment_build_status']._options = None
  _BUILD.fields_by_name['deployment_build_status']._serialized_options = b'\030\001'
  _DOCKERBUILD_BUILDARGSENTRY._options = None
  _DOCKERBUILD_BUILDARGSENTRY._serialized_options = b'8\001'
  _globals['_BUILDSTATUS']._serialized_start=6054
  _globals['_BUILDSTATUS']._serialized_end=6286
  _globals['_BUILD']._serialized_start=180
  _globals['_BUILD']._serialized_end=936
  _globals['_BUILDSPEC']._serialized_start=939
  _globals['_BUILDSPEC']._serialized_end=1329
  _globals['_MODELSCHEMA']._serialized_start=1332
  _globals['_MODELSCHEMA']._serialized_end=1570
  _globals['_ENTITY']._serialized_start=1572
  _globals['_ENTITY']._serialized_end=1643
  _globals['_FEATURE']._serialized_start=1646
  _globals['_FEATURE']._serialized_end=2238
  _globals['_ONTHEFLYFEATURE']._serialized_start=2241
  _globals['_ONTHEFLYFEATURE']._serialized_end=2384
  _globals['_BATCHFEATUREV1']._serialized_start=2386
  _globals['_BATCHFEATUREV1']._serialized_end=2464
  _globals['_STREAMINGFEATUREV1']._serialized_start=2466
  _globals['_STREAMINGFEATUREV1']._serialized_end=2548
  _globals['_BATCHFEATURE']._serialized_start=2550
  _globals['_BATCHFEATURE']._serialized_end=2626
  _globals['_STREAMINGFEATURE']._serialized_start=2628
  _globals['_STREAMINGFEATURE']._serialized_end=2708
  _globals['_STREAMINGAGGREGATIONFEATURE']._serialized_start=2710
  _globals['_STREAMINGAGGREGATIONFEATURE']._serialized_end=2801
  _globals['_EXPLICITFEATURE']._serialized_start=2803
  _globals['_EXPLICITFEATURE']._serialized_end=2883
  _globals['_REQUESTINPUT']._serialized_start=2885
  _globals['_REQUESTINPUT']._serialized_end=2962
  _globals['_SOURCEFEATURE']._serialized_start=2965
  _globals['_SOURCEFEATURE']._serialized_end=3120
  _globals['_PREDICTION']._serialized_start=3122
  _globals['_PREDICTION']._serialized_end=3197
  _globals['_INFERENCEOUTPUT']._serialized_start=3199
  _globals['_INFERENCEOUTPUT']._serialized_end=3279
  _globals['_VALUETYPE']._serialized_start=3282
  _globals['_VALUETYPE']._serialized_end=3448
  _globals['_VALUETYPE_TYPES']._serialized_start=3350
  _globals['_VALUETYPE_TYPES']._serialized_end=3448
  _globals['_PARAMETERCATEGORY']._serialized_start=3450
  _globals['_PARAMETERCATEGORY']._serialized_end=3556
  _globals['_PARAMETERCATEGORY_CATEGORY']._serialized_start=3471
  _globals['_PARAMETERCATEGORY_CATEGORY']._serialized_end=3556
  _globals['_REGISTERMODELSCHEMAREQUEST']._serialized_start=3558
  _globals['_REGISTERMODELSCHEMAREQUEST']._serialized_end=3663
  _globals['_REGISTEREXPERIMENTTRACKINGVALUESREQUEST']._serialized_start=3666
  _globals['_REGISTEREXPERIMENTTRACKINGVALUESREQUEST']._serialized_end=3811
  _globals['_REGISTEREXPERIMENTTRACKINGVALUESRESPONSE']._serialized_start=3813
  _globals['_REGISTEREXPERIMENTTRACKINGVALUESRESPONSE']._serialized_end=3855
  _globals['_EXPERIMENTTRACKINGVALUES']._serialized_start=3857
  _globals['_EXPERIMENTTRACKINGVALUES']._serialized_end=3979
  _globals['_BUILDCONFIGURATION']._serialized_start=3982
  _globals['_BUILDCONFIGURATION']._serialized_end=4319
  _globals['_STEP']._serialized_start=4321
  _globals['_STEP']._serialized_end=4416
  _globals['_BUILDPROPERTIESPROTO']._serialized_start=4419
  _globals['_BUILDPROPERTIESPROTO']._serialized_end=4615
  _globals['_BUILDMODELURI']._serialized_start=4617
  _globals['_BUILDMODELURI']._serialized_end=4720
  _globals['_BUILDENVIRONMENT']._serialized_start=4723
  _globals['_BUILDENVIRONMENT']._serialized_end=4955
  _globals['_DOCKERBUILD']._serialized_start=4958
  _globals['_DOCKERBUILD']._serialized_end=5224
  _globals['_DOCKERBUILD_BUILDARGSENTRY']._serialized_start=5176
  _globals['_DOCKERBUILD_BUILDARGSENTRY']._serialized_end=5224
  _globals['_LOCALBUILD']._serialized_start=5226
  _globals['_LOCALBUILD']._serialized_end=5276
  _globals['_PYTHONBUILD']._serialized_start=5279
  _globals['_PYTHONBUILD']._serialized_end=5562
  _globals['_CONDABUILD']._serialized_start=5564
  _globals['_CONDABUILD']._serialized_end=5596
  _globals['_POETRYBUILD']._serialized_start=5598
  _globals['_POETRYBUILD']._serialized_end=5654
  _globals['_VIRTUALENVIRONMENTBUILD']._serialized_start=5656
  _globals['_VIRTUALENVIRONMENTBUILD']._serialized_end=5731
  _globals['_REMOTEBUILD']._serialized_start=5733
  _globals['_REMOTEBUILD']._serialized_end=5830
  _globals['_REMOTEBUILDRESOURCES']._serialized_start=5833
  _globals['_REMOTEBUILDRESOURCES']._serialized_end=5976
  _globals['_METRIC']._serialized_start=5978
  _globals['_METRIC']._serialized_end=6014
  _globals['_PARAM']._serialized_start=6016
  _globals['_PARAM']._serialized_end=6051
# @@protoc_insertion_point(module_scope)
