# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/state/execution_state.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.execution.v1.state import spark_execution_state_pb2 as qwak_dot_execution_dot_v1_dot_state_dot_spark__execution__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-qwak/execution/v1/state/execution_state.proto\x12%qwak.feature.store.execution.v1.state\x1a\x33qwak/execution/v1/state/spark_execution_state.proto\"\xba\x01\n\x0e\x45xecutionState\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\x12\x15\n\rfeatureset_id\x18\x02 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x03 \x01(\t\x12U\n\x0fspark_app_state\x18\x04 \x01(\x0b\x32:.qwak.feature.store.execution.v1.state.SparkExecutionStateH\x00\x42\x0c\n\nexec_stateB`\n+com.qwak.ai.features.execution.api.v1.stateP\x01Z/qwak/execution_management/state;execution_stateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.execution.v1.state.execution_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n+com.qwak.ai.features.execution.api.v1.stateP\001Z/qwak/execution_management/state;execution_state'
  _globals['_EXECUTIONSTATE']._serialized_start=142
  _globals['_EXECUTIONSTATE']._serialized_end=328
# @@protoc_insertion_point(module_scope)
