"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.administration.runtime_configuration.v0.external.kafka_config_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ModelAnalyticsStorageConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KAFKA_FIELD_NUMBER: builtins.int
    @property
    def kafka(self) -> qwak.administration.runtime_configuration.v0.external.kafka_config_pb2.KafkaConfiguration: ...
    def __init__(
        self,
        *,
        kafka: qwak.administration.runtime_configuration.v0.external.kafka_config_pb2.KafkaConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["kafka", b"kafka", "storage_type", b"storage_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kafka", b"kafka", "storage_type", b"storage_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["storage_type", b"storage_type"]) -> typing_extensions.Literal["kafka"] | None: ...

global___ModelAnalyticsStorageConfiguration = ModelAnalyticsStorageConfiguration
