"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.model_group.model_group_repository_details_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GetModelGroupSystemPullImageSecretRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_GROUP_SYSTEM_PULL_SECRET_IDENTIFIERS_FIELD_NUMBER: builtins.int
    @property
    def model_group_system_pull_secret_identifiers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModelGroupSystemPullSecretIdentifier]: ...
    def __init__(
        self,
        *,
        model_group_system_pull_secret_identifiers: collections.abc.Iterable[global___ModelGroupSystemPullSecretIdentifier] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_group_system_pull_secret_identifiers", b"model_group_system_pull_secret_identifiers"]) -> None: ...

global___GetModelGroupSystemPullImageSecretRequest = GetModelGroupSystemPullImageSecretRequest

class ModelGroupSystemPullSecretIdentifier(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_GROUP_NAME_FIELD_NUMBER: builtins.int
    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    model_group_name: builtins.str
    account_id: builtins.str
    def __init__(
        self,
        *,
        model_group_name: builtins.str = ...,
        account_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model_group_identifier", b"model_group_identifier", "model_group_name", b"model_group_name"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "model_group_identifier", b"model_group_identifier", "model_group_name", b"model_group_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["model_group_identifier", b"model_group_identifier"]) -> typing_extensions.Literal["model_group_name"] | None: ...

global___ModelGroupSystemPullSecretIdentifier = ModelGroupSystemPullSecretIdentifier

class SystemPullSecretInfoNamesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_INFOS_FIELD_NUMBER: builtins.int
    @property
    def secret_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SystemPullSecretInfo]: ...
    def __init__(
        self,
        *,
        secret_infos: collections.abc.Iterable[global___SystemPullSecretInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["secret_infos", b"secret_infos"]) -> None: ...

global___SystemPullSecretInfoNamesResponse = SystemPullSecretInfoNamesResponse

class SystemPullSecretInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_GROUP_NAME_FIELD_NUMBER: builtins.int
    SECRET_PULL_IMAGE_FIELD_NUMBER: builtins.int
    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    model_group_name: builtins.str
    secret_pull_image: builtins.str
    account_id: builtins.str
    def __init__(
        self,
        *,
        model_group_name: builtins.str = ...,
        secret_pull_image: builtins.str = ...,
        account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "model_group_name", b"model_group_name", "secret_pull_image", b"secret_pull_image"]) -> None: ...

global___SystemPullSecretInfo = SystemPullSecretInfo

class CreateIfNotExistsModelGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_GROUP_NAME_FIELD_NUMBER: builtins.int
    JFROG_PROJECT_KEY_FIELD_NUMBER: builtins.int
    model_group_name: builtins.str
    """Model group name"""
    jfrog_project_key: builtins.str
    """Artifactory project key used for repository organization"""
    def __init__(
        self,
        *,
        model_group_name: builtins.str = ...,
        jfrog_project_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jfrog_project_key", b"jfrog_project_key", "model_group_name", b"model_group_name"]) -> None: ...

global___CreateIfNotExistsModelGroupRequest = CreateIfNotExistsModelGroupRequest

class ModelGroupBriefInfoResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_GROUP_ID_FIELD_NUMBER: builtins.int
    MODEL_GROUP_DESCRIPTION_FIELD_NUMBER: builtins.int
    MODEL_GROUP_CREATED_AT_FIELD_NUMBER: builtins.int
    REPOSITORY_DETAILS_FIELD_NUMBER: builtins.int
    model_group_id: builtins.str
    """Unique identifier for the model group"""
    model_group_description: builtins.str
    """Description of the model group"""
    @property
    def model_group_created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The model group creation timestamp"""
    @property
    def repository_details(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.model_group.model_group_repository_details_pb2.RepositoryDetails]:
        """List of repository details associated with this model group"""
    def __init__(
        self,
        *,
        model_group_id: builtins.str = ...,
        model_group_description: builtins.str = ...,
        model_group_created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        repository_details: collections.abc.Iterable[qwak.model_group.model_group_repository_details_pb2.RepositoryDetails] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model_group_created_at", b"model_group_created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_group_created_at", b"model_group_created_at", "model_group_description", b"model_group_description", "model_group_id", b"model_group_id", "repository_details", b"repository_details"]) -> None: ...

global___ModelGroupBriefInfoResponse = ModelGroupBriefInfoResponse

class CreateRepositoriesForModelGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_GROUP_UUID_FIELD_NUMBER: builtins.int
    REPOSITORY_DETAILS_FIELD_NUMBER: builtins.int
    model_group_uuid: builtins.str
    """the model group UUID for which to create repositories"""
    @property
    def repository_details(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.model_group.model_group_repository_details_pb2.RemoteRepositoryDetails]:
        """List of remote repository details to create for the model group"""
    def __init__(
        self,
        *,
        model_group_uuid: builtins.str = ...,
        repository_details: collections.abc.Iterable[qwak.model_group.model_group_repository_details_pb2.RemoteRepositoryDetails] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_group_uuid", b"model_group_uuid", "repository_details", b"repository_details"]) -> None: ...

global___CreateRepositoriesForModelGroupRequest = CreateRepositoriesForModelGroupRequest

class CreateRepositoriesForModelGroupResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARTIFACTORY_REPOSITORY_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def artifactory_repository_details(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.model_group.model_group_repository_details_pb2.RepositoryDetails]:
        """List of repository details associated with this model group"""
    def __init__(
        self,
        *,
        artifactory_repository_details: collections.abc.Iterable[qwak.model_group.model_group_repository_details_pb2.RepositoryDetails] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["artifactory_repository_details", b"artifactory_repository_details"]) -> None: ...

global___CreateRepositoriesForModelGroupResponse = CreateRepositoriesForModelGroupResponse

class GetModelGroupInfoRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_GROUP_NAME_FIELD_NUMBER: builtins.int
    JFROG_PROJECT_KEY_FIELD_NUMBER: builtins.int
    model_group_name: builtins.str
    """Model group name"""
    jfrog_project_key: builtins.str
    """Artifactory project key used for repository organization"""
    def __init__(
        self,
        *,
        model_group_name: builtins.str = ...,
        jfrog_project_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jfrog_project_key", b"jfrog_project_key", "model_group_name", b"model_group_name"]) -> None: ...

global___GetModelGroupInfoRequest = GetModelGroupInfoRequest
